diff --git a/src/or/dirserv.c b/src/or/dirserv.c
index a05ed98fa7..cbdfb6b0a7 100644
--- a/src/or/dirserv.c
+++ b/src/or/dirserv.c
@@ -178,20 +178,22 @@ dirserv_router_fingerprint_is_known(const routerinfo_t *router)
}
}
/** Return true iff any router named nickname is in the fingerprint
* list. */
static int
router_nickname_is_approved(const char *nickname, const char *digest)
{
int i,j;
fingerprint_entry_t *ent;
char fp[FINGERPRINT_LEN+1];
+ char hexdigest[HEX_DIGEST_LEN+1];
if (!fingerprint_list)
return 0;
- for (i=j=0;i
@@ -178,20 +178,22 @@ dirserv_router_fingerprint_is_known(const routerinfo_t *router)
}
}
-/** Return true iff any router named nickname is in the fingerprint
- * list. */
+/** Return true iff any router named nickname with digest
+ * is in the verified fingerprint list. */
static int
router_nickname_is_approved(const char *nickname, const char *digest)